==> js-language-24.0.0-sources.jar: com/oracle/truffle/js/builtins/commonjs/GlobalCommonJSRequireBuiltins.java <==
/*
 * Copyright (c) 2019, 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * The Universal Permissive License (UPL), Version 1.0
 *
 * Subject to the condition set forth below, permission is hereby granted to any
 * person obtaining a copy of this software, associated documentation and/or
 * data (collectively the "Software"), free of charge and under any and all
 * copyright rights in the Software, and any and all patent rights owned or
 * freely licensable by each licensor hereunder covering either (i) the
 * unmodified Software as contributed to or provided by such licensor, or (ii)
 * the Larger Works (as defined below), to deal in both
 *
 * (a) the Software, and
 *
 * (b) any piece of software and/or hardware listed in the lrgrwrks.txt file if
 * one is included with the Software each a "Larger Work" to which the Software
 * is contributed by such licensors),
 *
 * without restriction, including without limitation the rights to copy, create
 * derivative works of, display, perform, and distribute the Software and make,
 * use, sell, offer for sale, import, export, have made, and have sold the
 * Software and the Larger Work(s), and to sublicense the foregoing rights on
 * either these or other terms.
 *
 * This license is subject to the following condition:
 *
 * The above copyright notice and either this complete permission notice or at a
 * minimum a reference to the UPL must be included in all copies or substantial
 * portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package com.oracle.truffle.js.builtins.commonjs;

import com.oracle.truffle.js.builtins.JSBuiltinsContainer;
import com.oracle.truffle.js.nodes.function.JSBuiltin;
import com.oracle.truffle.js.runtime.JSContext;
import com.oracle.truffle.js.runtime.builtins.BuiltinEnum;

/**
 * Built-ins for CommonJS 'require' emulation.
 */
public class GlobalCommonJSRequireBuiltins extends JSBuiltinsContainer.SwitchEnum<GlobalCommonJSRequireBuiltins.GlobalRequire> {
    public GlobalCommonJSRequireBuiltins() {
        super(GlobalRequire.class);
    }

    public enum GlobalRequire implements BuiltinEnum<GlobalRequire> {
        require(1),
        dirnameGetter(0),
        filenameGetter(0),
        globalExportsGetter(0),
        globalModuleGetter(0),
        resolve(1);

        private final int length;

        GlobalRequire(int length) {
            this.length = length;
        }

        @Override
        public int getLength() {
            return length;
        }
    }

    @Override
    protected Object createNode(JSContext context, JSBuiltin builtin, boolean construct, boolean newTarget, GlobalRequire builtinEnum) {
        switch (builtinEnum) {
            case require:
                return CommonJSRequireBuiltinNodeGen.create(context, builtin, args().function().fixedArgs(1).createArgumentNodes(context));
            case resolve:
                return CommonJSResolveBuiltinNodeGen.create(context, builtin, args().fixedArgs(1).createArgumentNodes(context));
            case dirnameGetter:
                return CommonJSModuleGetterBuiltinNodeGen.create(context, builtin, builtinEnum, args().fixedArgs(0).createArgumentNodes(context));
            case filenameGetter:
                return CommonJSModuleGetterBuiltinNodeGen.create(context, builtin, builtinEnum, args().fixedArgs(0).createArgumentNodes(context));
            case globalExportsGetter:
                return CommonJSModuleGetterBuiltinNodeGen.create(context, builtin, builtinEnum, args().fixedArgs(0).createArgumentNodes(context));
            case globalModuleGetter:
                return CommonJSModuleGetterBuiltinNodeGen.create(context, builtin, builtinEnum, args().fixedArgs(0).createArgumentNodes(context));
        }
        return null;
    }
}

==> js-language-25.0.0-sources.jar: com/oracle/truffle/js/builtins/commonjs/GlobalCommonJSRequireBuiltins.java <==
/*
 * Copyright (c) 2019, 2024, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * The Universal Permissive License (UPL), Version 1.0
 *
 * Subject to the condition set forth below, permission is hereby granted to any
 * person obtaining a copy of this software, associated documentation and/or
 * data (collectively the "Software"), free of charge and under any and all
 * copyright rights in the Software, and any and all patent rights owned or
 * freely licensable by each licensor hereunder covering either (i) the
 * unmodified Software as contributed to or provided by such licensor, or (ii)
 * the Larger Works (as defined below), to deal in both
 *
 * (a) the Software, and
 *
 * (b) any piece of software and/or hardware listed in the lrgrwrks.txt file if
 * one is included with the Software each a "Larger Work" to which the Software
 * is contributed by such licensors),
 *
 * without restriction, including without limitation the rights to copy, create
 * derivative works of, display, perform, and distribute the Software and make,
 * use, sell, offer for sale, import, export, have made, and have sold the
 * Software and the Larger Work(s), and to sublicense the foregoing rights on
 * either these or other terms.
 *
 * This license is subject to the following condition:
 *
 * The above copyright notice and either this complete permission notice or at a
 * minimum a reference to the UPL must be included in all copies or substantial
 * portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package com.oracle.truffle.js.builtins.commonjs;

import com.oracle.truffle.js.builtins.JSBuiltinsContainer;
import com.oracle.truffle.js.nodes.function.JSBuiltin;
import com.oracle.truffle.js.runtime.JSContext;
import com.oracle.truffle.js.runtime.builtins.BuiltinEnum;

/**
 * Built-ins for CommonJS 'require' emulation.
 */
public class GlobalCommonJSRequireBuiltins extends JSBuiltinsContainer.SwitchEnum<GlobalCommonJSRequireBuiltins.GlobalRequire> {

    public static final JSBuiltinsContainer GLOBAL_COMMONJS_REQUIRE_EXTENSIONS = new GlobalCommonJSRequireBuiltins();

    public GlobalCommonJSRequireBuiltins() {
        super(GlobalRequire.class);
    }

    public enum GlobalRequire implements BuiltinEnum<GlobalRequire> {
        require(1),
        dirnameGetter(0),
        filenameGetter(0),
        globalExportsGetter(0),
        globalModuleGetter(0),
        resolve(1);

        private final int length;

        GlobalRequire(int length) {
            this.length = length;
        }

        @Override
        public int getLength() {
            return length;
        }
    }

    @Override
    protected Object createNode(JSContext context, JSBuiltin builtin, boolean construct, boolean newTarget, GlobalRequire builtinEnum) {
        switch (builtinEnum) {
            case require:
                return CommonJSRequireBuiltinNodeGen.create(context, builtin, args().function().fixedArgs(1).createArgumentNodes(context));
            case resolve:
                return CommonJSResolveBuiltinNodeGen.create(context, builtin, args().fixedArgs(1).createArgumentNodes(context));
            case dirnameGetter, filenameGetter, globalExportsGetter, globalModuleGetter:
                return CommonJSModuleGetterBuiltinNodeGen.create(context, builtin, builtinEnum, args().fixedArgs(0).createArgumentNodes(context));
        }
        return null;
    }
}
